@@ -183,7 +183,7 @@ sub initialize { shift }
 
 =head2 contains
 
-  $bool = $self->get('/json/2/pointer');
+  $bool = $self->contains('/json/2/pointer');
 
 Use L<Mojo::JSON::Pointer/contains> to check if a value exists inside the raw
 mongodb document.
@@ -407,8 +407,10 @@ sub import {
   my $model = Mandel::Model->new(document_class => $caller, %args);
   my $base_class = 'Mandel::Document';
 
-  if($args{name} and $args{name} =~ /::/) {
-    $base_class = delete $args{name};
+  for (qw/name extends/) { 
+    if($args{$_} and $args{$_} =~ /::/) {
+      $base_class = delete $args{$_};
+    }
   }
   if(!$args{name}) {
     $args{name} = Mojo::Util::decamelize(($caller =~ /(\w+)$/)[0]);
